import tgram
from .type_ import Type_

from typing import Optional


class Audio(Type_):
    """
    This object represents an audio file to be treated as music by the Telegram clients.

    Telegram Documentation: https://core.telegram.org/bots/api#audio

    :param file_id: Identifier for this file, which can be used to download or reuse the file
    :type file_id: :obj:`str`

    :param file_unique_id: Unique identifier for this file, which is supposed to be the same over time and for different
        bots. Can't be used to download or reuse the file.
    :type file_unique_id: :obj:`str`

    :param duration: Duration of the audio in seconds as defined by sender
    :type duration: :obj:`int`

    :param performer: Optional. Performer of the audio as defined by sender or by audio tags
    :type performer: :obj:`str`

    :param title: Optional. Title of the audio as defined by sender or by audio tags
    :type title: :obj:`str`

    :param file_name: Optional. Original filename as defined by sender
    :type file_name: :obj:`str`

    :param mime_type: Optional. MIME type of the file as defined by sender
    :type mime_type: :obj:`str`

    :param file_size: Optional. File size in bytes. It can be bigger than 2^31 and some programming languages may have
        difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a signed 64-bit integer or
        double-precision float type are safe for storing this value.
    :type file_size: :obj:`int`

    :param thumbnail: Optional. Thumbnail of the album cover to which the music file belongs
    :type thumbnail: :class:`tgram.types.PhotoSize`

    :return: Instance of the class
    :rtype: :class:`tgram.types.Audio`
    """

    def __init__(
        self,
        file_id: "str" = None,
        file_unique_id: "str" = None,
        duration: "int" = None,
        performer: "str" = None,
        title: "str" = None,
        file_name: "str" = None,
        mime_type: "str" = None,
        file_size: "int" = None,
        thumbnail: "tgram.types.PhotoSize" = None,
        me: "tgram.TgBot" = None,
        json: "dict" = None,
    ):
        super().__init__(me=me, json=json)
        self.file_id = file_id
        self.file_unique_id = file_unique_id
        self.duration = duration
        self.performer = performer
        self.title = title
        self.file_name = file_name
        self.mime_type = mime_type
        self.file_size = file_size
        self.thumbnail = thumbnail

    @staticmethod
    def _parse(
        me: "tgram.TgBot" = None, d: dict = None, force: bool = None
    ) -> Optional["tgram.types.Audio"]:
        return (
            Audio(
                me=me,
                json=d,
                file_id=d.get("file_id"),
                file_unique_id=d.get("file_unique_id"),
                duration=d.get("duration"),
                performer=d.get("performer"),
                title=d.get("title"),
                file_name=d.get("file_name"),
                mime_type=d.get("mime_type"),
                file_size=d.get("file_size"),
                thumbnail=tgram.types.PhotoSize._parse(me=me, d=d.get("thumbnail")),
            )
            if d and (force or me and __class__.__name__ not in me._custom_types)
            else None
            if not d
            else Type_._custom_parse(
                __class__._parse(me=me, d=d, force=True),
                me._custom_types.get(__class__.__name__),
            )
        )



import tgram
from .type_ import Type_

from typing import Optional


class ChatBoostSourceGiftCode(Type_):
    """
    The boost was obtained by the creation of Telegram Premium gift codes to boost a chat.

    Telegram documentation: https://core.telegram.org/bots/api#chatboostsourcegiftcode

    :param source: Source of the boost, always “gift_code”
    :type source: :obj:`str`

    :param user: User for which the gift code was created
    :type user: :class:`User`

    :return: Instance of the class
    :rtype: :class:`ChatBoostSourceGiftCode`
    """

    def __init__(
        self,
        source: "str" = None,
        user: "tgram.types.User" = None,
        me: "tgram.TgBot" = None,
        json: "dict" = None,
    ):
        super().__init__(me=me, json=json)
        self.source = source
        self.user = user

    @staticmethod
    def _parse(
        me: "tgram.TgBot" = None, d: dict = None, force: bool = None
    ) -> Optional["tgram.types.ChatBoostSourceGiftCode"]:
        return (
            ChatBoostSourceGiftCode(
                me=me,
                json=d,
                source=d.get("source"),
                user=tgram.types.User._parse(me=me, d=d.get("user")),
            )
            if d and (force or me and __class__.__name__ not in me._custom_types)
            else None
            if not d
            else Type_._custom_parse(
                __class__._parse(me=me, d=d, force=True),
                me._custom_types.get(__class__.__name__),
            )
        )



import tgram
from .type_ import Type_

from typing import List, Union, Optional

from pathlib import Path


class InputMediaDocument(Type_):
    """
    Represents a general file to be sent.

    Telegram Documentation: https://core.telegram.org/bots/api#inputmediadocument

    :param media: File to send. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an
        HTTP URL for Telegram to get a file from the Internet, or pass “attach://<file_attach_name>” to upload a new one using
        multipart/form-data under <file_attach_name> name. More information on Sending Files »
    :type media: :obj:`str`

    :param thumbnail: Optional. Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported
        server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail's width and height should
        not exceed 320. Ignored if the file is not uploaded using multipart/form-data. Thumbnails can't be reused and can be
        only uploaded as a new file, so you can pass “attach://<file_attach_name>” if the thumbnail was uploaded using
        multipart/form-data under <file_attach_name>. More information on Sending Files »
    :type thumbnail: InputFile or :obj:`str`

    :param caption: Optional. Caption of the document to be sent, 0-1024 characters after entities parsing
    :type caption: :obj:`str`

    :param parse_mode: Optional. Mode for parsing entities in the document caption. See formatting options for more
        details.
    :type parse_mode: :obj:`str`

    :param caption_entities: Optional. List of special entities that appear in the caption, which can be specified
        instead of parse_mode
    :type caption_entities: :obj:`list` of :class:`tgram.types.MessageEntity`

    :param disable_content_type_detection: Optional. Disables automatic server-side content type detection for
        files uploaded using multipart/form-data. Always True, if the document is sent as part of an album.
    :type disable_content_type_detection: :obj:`bool`

    :return: Instance of the class
    :rtype: :class:`tgram.types.InputMediaDocument`
    """

    def __init__(
        self,
        media: Union["Path", "str"] = None,
        thumbnail: Union["tgram.types.InputFile", "str"] = None,
        caption: "str" = None,
        parse_mode: "str" = None,
        caption_entities: List["tgram.types.MessageEntity"] = None,
        disable_content_type_detection: "bool" = None,
        me: "tgram.TgBot" = None,
        json: "dict" = None,
    ):
        super().__init__(me=me, json=json)
        self.type = "document"
        self.media = media
        self.thumbnail = thumbnail
        self.caption = caption
        self.parse_mode = parse_mode
        self.caption_entities = caption_entities
        self.disable_content_type_detection = disable_content_type_detection

    @staticmethod
    def _parse(
        me: "tgram.TgBot" = None, d: dict = None, force: bool = None
    ) -> Optional["tgram.types.InputMediaDocument"]:
        return (
            InputMediaDocument(
                me=me,
                json=d,
                media=d.get("media"),
                thumbnail=d.get("thumbnail"),
                caption=d.get("caption"),
                parse_mode=d.get("parse_mode"),
                caption_entities=[
                    tgram.types.MessageEntity._parse(me=me, d=i)
                    for i in d.get("caption_entities")
                ]
                if d.get("caption_entities")
                else None,
                disable_content_type_detection=d.get("disable_content_type_detection"),
            )
            if d and (force or me and __class__.__name__ not in me._custom_types)
            else None
            if not d
            else Type_._custom_parse(
                __class__._parse(me=me, d=d, force=True),
                me._custom_types.get(__class__.__name__),
            )
        )



import tgram
from .type_ import Type_

from typing import List, Optional


class UsersShared(Type_):
    """
    This object contains information about the users whose identifiers were shared with the bot
    using a KeyboardButtonRequestUsers button.

    Telegram documentation: https://core.telegram.org/bots/api#usersshared

    :param request_id: Identifier of the request
    :type request_id: :obj:`int`

    :param users: Information about users shared with the bot
    :type users: :obj:`list` of :obj:`types.SharedUser`

    :return: Instance of the class
    :rtype: :class:`UsersShared`
    """

    def __init__(
        self,
        request_id: "int" = None,
        users: List["tgram.types.SharedUser"] = None,
        me: "tgram.TgBot" = None,
        json: "dict" = None,
    ):
        super().__init__(me=me, json=json)
        self.request_id = request_id
        self.users = users

    @staticmethod
    def _parse(
        me: "tgram.TgBot" = None, d: dict = None, force: bool = None
    ) -> Optional["tgram.types.UsersShared"]:
        return (
            UsersShared(
                me=me,
                json=d,
                request_id=d.get("request_id"),
                users=[
                    tgram.types.SharedUser._parse(me=me, d=i) for i in d.get("users")
                ]
                if d.get("users")
                else None,
            )
            if d and (force or me and __class__.__name__ not in me._custom_types)
            else None
            if not d
            else Type_._custom_parse(
                __class__._parse(me=me, d=d, force=True),
                me._custom_types.get(__class__.__name__),
            )
        )



import asyncio
import tgram

from typing import List


async def compose(bots: List["tgram.TgBot"]):
    tasks = [asyncio.create_task(bot.run_for_updates()) for bot in bots]

    return await asyncio.wait(tasks)



from tgram import TgBot, filters
from tgram.types import Message


@TgBot.on_message(filters.command("start") & filters.private)
async def on_start_command(bot: TgBot, m: Message) -> Message:
    await m.react("❤️")
    return await m.reply_text(
        "Hi from [Tgram](https://github.com/z44d/tgram)", parse_mode="markdown"
    )



import tgram
from .type_ import Type_

from typing import Optional


class ChatBoostAdded(Type_):
    """
    This object represents a service message about a user boosting a chat.

    Telegram documentation: https://core.telegram.org/bots/api#chatboostadded

    :param boost_count: Number of boosts added by the user
    :type boost_count: :obj:`int`

    :return: Instance of the class
    :rtype: :class:`ChatBoostAdded`
    """

    def __init__(
        self,
        boost_count: "int" = None,
        me: "tgram.TgBot" = None,
        json: "dict" = None,
    ):
        super().__init__(me=me, json=json)
        self.boost_count = boost_count

    @staticmethod
    def _parse(
        me: "tgram.TgBot" = None, d: dict = None, force: bool = None
    ) -> Optional["tgram.types.ChatBoostAdded"]:
        return (
            ChatBoostAdded(me=me, json=d, boost_count=d.get("boost_count"))
            if d and (force or me and __class__.__name__ not in me._custom_types)
            else None
            if not d
            else Type_._custom_parse(
                __class__._parse(me=me, d=d, force=True),
                me._custom_types.get(__class__.__name__),
            )
        )



from argparse import ArgumentParser, Namespace


def parse_arguments() -> Namespace:
    parser = ArgumentParser(
        description="This script is only to generate ready-template :)"
    )

    parser.add_argument("-t", "--template", required=True, action="store_true")

    return parser.parse_args()


def main():
    args = parse_arguments()

    if args.template:
        TEMPLATE = {
            ".env": "https://raw.githubusercontent.com/z44d/tgram/refs/heads/main/tgram/template/.env",
            ".gitignore": "https://raw.githubusercontent.com/z44d/tgram/refs/heads/main/tgram/template/.gitignore",
            "README.md": "https://raw.githubusercontent.com/z44d/tgram/refs/heads/main/tgram/template/generate.md",
            "config.py": "https://raw.githubusercontent.com/z44d/tgram/refs/heads/main/tgram/template/config.py",
            "main.py": "https://raw.githubusercontent.com/z44d/tgram/refs/heads/main/tgram/template/main.py",
            "requirements.txt": "https://raw.githubusercontent.com/z44d/tgram/refs/heads/main/tgram/template/requirements.txt",
        }

        import requests

        print("Generating ready-template..")

        for i in TEMPLATE:
            with open(i, "w+", encoding="utf-8") as f:
                f.write(requests.get(TEMPLATE.get(i)).text)

                print(f"File [ {i} ] has been generated.")

        import os

        if not os.path.isdir("plugins"):
            os.mkdir("plugins")

        with open("plugins/start.py", "w+", encoding="utf-8") as f:
            f.write(
                requests.get(
                    "https://raw.githubusercontent.com/z44d/tgram/refs/heads/main/tgram/template/plugins/start.py"
                ).text
            )

            print("Plugins folder has been generated.")

        print("\033[92m" + "GENERATED SUCCESSFULLY")


if __name__ == "__main__":
    main()



__all__ = [
    "types",
    "TgBot",
    "handlers",
    "filters",
    "compose",
    "StopPropagation",
    "utils",
    "storage",
]
__version__ = "1.11.8"

from . import filters, utils, storage, handlers, types

from .client import TgBot
from .sync import compose

from .errors import StopPropagation



import tgram
from .type_ import Type_

from typing import Union, Optional

from pathlib import Path


class InputPaidMediaVideo(Type_):
    """
    The paid media to send is a video.

    Telegram documentation: https://core.telegram.org/bots/api#inputpaidmediavideo

    :param type: Type of the media, must be video
    :type type: :obj:`str`

    :param media: File to send. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for
        Telegram to get a file from the Internet, or pass “attach://<file_attach_name>” to upload a new one using multipart/form-data
        under <file_attach_name> name. More information on Sending Files »
    :type media: :obj:`str`

    :param thumbnail: Optional. Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side.
        The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail's width and height should not exceed 320.
        Ignored if the file is not uploaded using multipart/form-data. Thumbnails can't be reused and can be only uploaded as a new file,
        so you can pass “attach://<file_attach_name>” if the thumbnail was uploaded using multipart/form-data under <file_attach_name>.
        More information on Sending Files »
    :type thumbnail: :class:`InputFile`

    :param width: Optional. Video width
    :type width: :obj:`int`

    :param height: Optional. Video height
    :type height: :obj:`int`

    :param duration: Optional. Video duration in seconds
    :type duration: :obj:`int`

    :param supports_streaming: Optional. Pass True if the uploaded video is suitable for streaming
    :type supports_streaming: :obj:`bool`

    :return: Instance of the class
    :rtype: :class:`InputPaidMediaVideo`

    """

    def __init__(
        self,
        media: Union["Path", "str"] = None,
        thumbnail: Union["tgram.types.InputFile", "str"] = None,
        width: "int" = None,
        height: "int" = None,
        duration: "int" = None,
        supports_streaming: "bool" = None,
        me: "tgram.TgBot" = None,
        json: "dict" = None,
    ):
        super().__init__(me=me, json=json)
        self.type = "video"
        self.media = media
        self.thumbnail = thumbnail
        self.width = width
        self.height = height
        self.duration = duration
        self.supports_streaming = supports_streaming

    @staticmethod
    def _parse(
        me: "tgram.TgBot" = None, d: dict = None, force: bool = None
    ) -> Optional["tgram.types.InputPaidMediaVideo"]:
        return (
            InputPaidMediaVideo(
                me=me,
                json=d,
                type=d.get("type"),
                media=d.get("media"),
                thumbnail=d.get("thumbnail"),
                width=d.get("width"),
                height=d.get("height"),
                duration=d.get("duration"),
                supports_streaming=d.get("supports_streaming"),
            )
            if d and (force or me and __class__.__name__ not in me._custom_types)
            else None
            if not d
            else Type_._custom_parse(
                __class__._parse(me=me, d=d, force=True),
                me._custom_types.get(__class__.__name__),
            )
        )



import os
import argparse
import requests
import re
import json

from tgram import TgBot


methods = [
    *["_send_request"],
    *[i for i in filter(lambda x: not x.startswith("_"), dir(TgBot))],
]


def camel_to_snake(name):
    snake = re.sub(r"(?<!^)(?=[A-Z])", "_", name).lower()
    return snake


def generate():
    TEMPLATE = {
        ".env": "https://raw.githubusercontent.com/z44d/tgram/refs/heads/main/tgram/cli/template/.env",
        ".gitignore": "https://raw.githubusercontent.com/z44d/tgram/refs/heads/main/tgram/cli/template/.gitignore",
        "README.md": "https://raw.githubusercontent.com/z44d/tgram/refs/heads/main/tgram/cli/template/generate.md",
        "config.py": "https://raw.githubusercontent.com/z44d/tgram/refs/heads/main/tgram/cli/template/config.py",
        "main.py": "https://raw.githubusercontent.com/z44d/tgram/refs/heads/main/tgram/cli/template/main.py",
        "requirements.txt": "https://raw.githubusercontent.com/z44d/tgram/refs/heads/main/tgram/cli/template/requirements.txt",
    }

    print("Generating ready-template..")

    for i in TEMPLATE:
        with open(i, "w+", encoding="utf-8") as f:
            f.write(requests.get(TEMPLATE.get(i)).text)

            print(f"File [ {i} ] has been generated.")

    if not os.path.isdir("plugins"):
        os.mkdir("plugins")

    with open("plugins/start.py", "w+", encoding="utf-8") as f:
        f.write(
            requests.get(
                "https://raw.githubusercontent.com/z44d/tgram/refs/heads/main/tgram/cli/template/plugins/start.py"
            ).text
        )

        print("Plugins folder has been generated.")

    print("\033[92m" + "GENERATED SUCCESSFULLY")


def main():
    parser = argparse.ArgumentParser()

    parser.add_argument("-t", "--template", required=False, action="store_true")
    parser.add_argument(
        "--token", type=str, required=False, help="Your Telegram bot token"
    )
    parser.add_argument(
        "--method",
        type=str,
        required=False,
        help="Telegram API method (e.g., sendMessage)",
    )
    parser.add_argument("args", nargs="*", default=[])

    args = parser.parse_args()

    if args.template:
        return generate()

    elif not args.token and not args.method:
        print(
            "You have to use tgram [-t] to generate a ready-to-use template, otherwise you have to use [--token] & [--method] \n"
            + "For Example: [tgram --token TOKEN --method sendMessage chat_id hi]"
        )

    else:
        token, method, args = (
            args.token,
            camel_to_snake(args.method.replace("send_request", "_send_request")),
            json.loads(args.args[0]) if len(args.args) == 1 else tuple(args.args),
        )
        try:
            bot = TgBot(token)

            if method not in methods:
                print("Wrong method [{}]".format(method))

            func = getattr(bot, method)

            if isinstance(args, dict):
                r = func(**args)
            else:
                r = func(*args)

            print(r)
        except Exception as e:
            print(e)


if __name__ == "__main__":
    main()



import tgram
import os

from typing import Optional, List, Union
from pathlib import Path
from io import BytesIO

from tgram import utils


def message_origin_parse(
    d: Optional[dict] = None, me: Optional["tgram.TgBot"] = None
) -> Optional["tgram.types.MessageOrigin"]:
    if d is None:
        return None

    origin_type = d["type"]

    return (
        tgram.types.MessageOriginUser._parse(me=me, d=d)
        if origin_type == "user"
        else tgram.types.MessageOriginHiddenUser._parse(me=me, d=d)
        if origin_type == "hidden_user"
        else tgram.types.MessageOriginChat._parse(me=me, d=d)
        if origin_type == "chat"
        else tgram.types.MessageOriginChannel._parse(me=me, d=d)
    )


def convert_input_media(
    x: List[Union["tgram.types.InputMedia", "tgram.types.InputPaidMedia"]],
):
    files = {}
    count = 1
    for y in x:
        if (
            isinstance(y.media, (Path, str))
            and os.path.isfile(y.media)
            or isinstance(y.media, (bytes, BytesIO))
        ):
            files[f"file_{count}"] = utils.get_file_path(y.media)
            y.media = f"attach://file_{count}"
            count += 1

            if hasattr(y, "thumbnail") and getattr(y, "thumbnail"):
                if (
                    isinstance(y.thumbnail, (Path, str)) and os.path.isfile(y.thumbnail)
                ) or isinstance(y.thumbnail, (bytes, BytesIO)):
                    files[f"file_{count}"] = utils.get_file_path(y.thumbnail)
                    y.thumbnail = f"attach://file_{count}"
                    count += 1

    return x, files



import tgram
import random
from .type_ import Type_

from typing import Optional


class InlineQueryResultCachedSticker(Type_):
    """
    Represents a link to a sticker stored on the Telegram servers. By default, this sticker will be sent by the user. Alternatively, you can use input_message_content to send a message with the specified content instead of the sticker.

    Telegram Documentation: https://core.telegram.org/bots/api#inlinequeryresultcachedsticker

    :param type: Type of the result, must be sticker
    :type type: :obj:`str`

    :param id: Unique identifier for this result, 1-64 bytes
    :type id: :obj:`str`

    :param sticker_file_id: A valid file identifier of the sticker
    :type sticker_file_id: :obj:`str`

    :param reply_markup: Optional. Inline keyboard attached to the message
    :type reply_markup: :class:`tgram.types.InlineKeyboardMarkup`

    :param input_message_content: Optional. Content of the message to be sent instead of the sticker
    :type input_message_content: :class:`tgram.types.InputMessageContent`

    :return: Instance of the class
    :rtype: :class:`tgram.types.InlineQueryResultCachedSticker`
    """

    def __init__(
        self,
        sticker_file_id: "str" = None,
        reply_markup: "tgram.types.InlineKeyboardMarkup" = None,
        input_message_content: "tgram.types.InputMessageContent" = None,
        me: "tgram.TgBot" = None,
        json: "dict" = None,
    ):
        super().__init__(me=me, json=json)
        self.type = "cachedsticker"
        self.id = random.randint(10000, 99999)
        self.sticker_file_id = sticker_file_id
        self.reply_markup = reply_markup
        self.input_message_content = input_message_content

    @staticmethod
    def _parse(
        me: "tgram.TgBot" = None, d: dict = None, force: bool = None
    ) -> Optional["tgram.types.InlineQueryResultCachedSticker"]:
        return (
            InlineQueryResultCachedSticker(
                me=me,
                json=d,
                sticker_file_id=d.get("sticker_file_id"),
                reply_markup=tgram.types.InlineKeyboardMarkup._parse(
                    me=me, d=d.get("reply_markup")
                ),
                input_message_content=tgram.types.InputMessageContent._parse(
                    me=me, d=d.get("input_message_content")
                ),
            )
            if d and (force or me and __class__.__name__ not in me._custom_types)
            else None
            if not d
            else Type_._custom_parse(
                __class__._parse(me=me, d=d, force=True),
                me._custom_types.get(__class__.__name__),
            )
        )



import tgram
from .type_ import Type_

from typing import Optional


class BotCommand(Type_):
    """
    This object represents a bot command.

    Telegram Documentation: https://core.telegram.org/bots/api#botcommand

    :param command: Text of the command; 1-32 characters. Can contain only lowercase English letters, digits and
        underscores.
    :type command: :obj:`str`

    :param description: Description of the command; 1-256 characters.
    :type description: :obj:`str`

    :return: Instance of the class
    :rtype: :class:`tgram.types.BotCommand`
    """

    def __init__(
        self,
        command: "str" = None,
        description: "str" = None,
        me: "tgram.TgBot" = None,
        json: "dict" = None,
    ):
        super().__init__(me=me, json=json)
        self.command = command
        self.description = description

    @staticmethod
    def _parse(
        me: "tgram.TgBot" = None, d: dict = None, force: bool = None
    ) -> Optional["tgram.types.BotCommand"]:
        return (
            BotCommand(
                me=me,
                json=d,
                command=d.get("command"),
                description=d.get("description"),
            )
            if d and (force or me and __class__.__name__ not in me._custom_types)
            else None
            if not d
            else Type_._custom_parse(
                __class__._parse(me=me, d=d, force=True),
                me._custom_types.get(__class__.__name__),
            )
        )



import sys
import asyncio
import logging
import platform

from tgram import TgBot

# from tgram.types import LinkPreviewOptions
from config import BOT_TOKEN

logging.basicConfig(level=logging.INFO)
py_version = sys.version_info[:2]
logger = logging.getLogger(__name__)


async def main():
    bot = TgBot(
        BOT_TOKEN,
        # parse_mode="Markdown",
        # link_preview_options=LinkPreviewOptions(is_disabled=True),
        plugins="./plugins",
        retry_after=15,
    )

    await bot.run()


def run_in_regular_event_loop():
    try:
        loop = asyncio.get_event_loop()
    except RuntimeError:
        loop = asyncio.new_event_loop()
        asyncio.set_event_loop(loop)

    loop.run_until_complete(main())


if __name__ == "__main__":
    if platform.system() == "Linux":
        try:
            import uvloop

            if py_version >= (3, 11):
                with asyncio.Runner(loop_factory=uvloop.new_event_loop) as runner:
                    runner.run(main())
            else:
                uvloop.install()
                asyncio.run(main())
        except ModuleNotFoundError:
            logger.warning(
                "You are a Linux user, so it's better to install and use uvloop as ultra-fast event loop, see more: https://github.com/MagicStack/uvloop"
            )
            run_in_regular_event_loop()
    else:
        run_in_regular_event_loop()



import tgram
from typing import Union
from tgram.types import ForceReply
from tgram.types import InlineKeyboardMarkup
from tgram.types import Message
from tgram.types import ReplyKeyboardMarkup
from tgram.types import ReplyKeyboardRemove
from tgram.types import ReplyParameters


class SendVenue:
    async def send_venue(
        self: "tgram.TgBot",
        chat_id: Union[int, str],
        latitude: float,
        longitude: float,
        title: str,
        address: str,
        business_connection_id: str = None,
        message_thread_id: int = None,
        foursquare_id: str = None,
        foursquare_type: str = None,
        google_place_id: str = None,
        google_place_type: str = None,
        disable_notification: bool = None,
        protect_content: bool = None,
        message_effect_id: str = None,
        reply_parameters: ReplyParameters = None,
        reply_markup: Union[
            InlineKeyboardMarkup, ReplyKeyboardMarkup, ReplyKeyboardRemove, ForceReply
        ] = None,
    ) -> Message:
        """
        Use this method to send information about a venue. On success, the sent Message is returned.

        Telegram documentation: https://core.telegram.org/bots/api#sendvenue

        :param chat_id: Unique identifier for the target chat or username of the target channel
        :type chat_id: :obj:`int` or :obj:`str`

        :param latitude: Latitude of the venue
        :type latitude: :obj:`float`

        :param longitude: Longitude of the venue
        :type longitude: :obj:`float`

        :param title: Name of the venue
        :type title: :obj:`str`

        :param address: Address of the venue
        :type address: :obj:`str`

        :param foursquare_id: Foursquare identifier of the venue
        :type foursquare_id: :obj:`str`

        :param foursquare_type: Foursquare type of the venue, if known. (For example, “arts_entertainment/default”,
            “arts_entertainment/aquarium” or “food/icecream”.)
        :type foursquare_type: :obj:`str`

        :param disable_notification: Sends the message silently. Users will receive a notification with no sound.
        :type disable_notification: :obj:`bool`

        :param reply_to_message_id: Deprecated - Use reply_parameters instead. If the message is a reply, ID of the original message
        :type reply_to_message_id: :obj:`int`

        :param reply_markup: Additional interface options. A JSON-serialized object for an inline keyboard,
            custom reply keyboard, instructions to remove reply keyboard or to force a reply from the user.
        :type reply_markup: :class:`tgram.types.InlineKeyboardMarkup` or :class:`tgram.types.ReplyKeyboardMarkup` or :class:`tgram.types.ReplyKeyboardRemove`
            or :class:`tgram.types.ForceReply`

        :param timeout: Timeout in seconds for the request.
        :type timeout: :obj:`int`

        :param allow_sending_without_reply: Deprecated - Use reply_parameters instead. Pass True, if the message should be sent even if one of the specified
            replied-to messages is not found.
        :type allow_sending_without_reply: :obj:`bool`

        :param google_place_id: Google Places identifier of the venue
        :type google_place_id: :obj:`str`

        :param google_place_type: Google Places type of the venue.
        :type google_place_type: :obj:`str`

        :param protect_content: Protects the contents of the sent message from forwarding and saving
        :type protect_content: :obj:`bool`

        :param message_thread_id: The thread to which the message will be sent
        :type message_thread_id: :obj:`int`

        :param reply_parameters: Reply parameters.
        :type reply_parameters: :class:`tgram.types.ReplyParameters`

        :param business_connection_id: Identifier of a business connection, in which the message will be sent
        :type business_connection_id: :obj:`str`

        :param message_effect_id: Unique identifier of the message effect
        :type message_effect_id: :obj:`str`

        :return: On success, the sent Message is returned.
        :rtype: :class:`tgram.types.Message`
        """

        result = await self._send_request(
            "sendVenue",
            chat_id=chat_id,
            latitude=latitude,
            longitude=longitude,
            title=title,
            address=address,
            business_connection_id=business_connection_id,
            message_thread_id=message_thread_id,
            foursquare_id=foursquare_id,
            foursquare_type=foursquare_type,
            google_place_id=google_place_id,
            google_place_type=google_place_type,
            disable_notification=disable_notification,
            protect_content=protect_content
            if protect_content is not None
            else self.protect_content,
            message_effect_id=message_effect_id,
            reply_parameters=reply_parameters,
            reply_markup=reply_markup,
        )
        return Message._parse(me=self, d=result["result"])



import tgram
from typing import List
from typing import Union
from tgram.types import InlineKeyboardMarkup
from tgram.types import LinkPreviewOptions
from tgram.types import Message
from tgram.types import MessageEntity, ParseMode

from tgram.utils import get_parse_mode


class EditMessageText:
    async def edit_message_text(
        self: "tgram.TgBot",
        text: str,
        business_connection_id: str = None,
        chat_id: Union[int, str] = None,
        message_id: int = None,
        inline_message_id: str = None,
        parse_mode: ParseMode = None,
        entities: List[MessageEntity] = None,
        link_preview_options: LinkPreviewOptions = None,
        reply_markup: InlineKeyboardMarkup = None,
    ) -> Union[Message, bool]:
        result = await self._send_request(
            "editMessageText",
            text=text,
            business_connection_id=business_connection_id,
            chat_id=chat_id,
            message_id=message_id,
            inline_message_id=inline_message_id,
            parse_mode=get_parse_mode(self, parse_mode),
            entities=entities,
            link_preview_options=link_preview_options or self.link_preview_options,
            reply_markup=reply_markup,
        )
        return (
            Message._parse(me=self, d=result["result"])
            if isinstance(result["result"], dict)
            else result["result"]
        )
